@@ -32,6 +32,7 @@
 
 #include <KConfigDialog>
 #include <KDatePicker>
+#include <KDebug>
 #include <KFileDialog>
 #include <KIO/NetAccess>
 #include <knuminput.h>
@@ -113,6 +114,7 @@ ComicApplet::ComicApplet( QObject *parent, const QVariantList &args )
       mShowComicAuthor( false ),
       mShowComicTitle( false ),
       mShowComicIdentifier( false ),
+      mShowErrorPicture( true ),
       mArrowsOnHover( true ),
       mMiddleClick( true ),
       mMainWidget( 0 ),
@@ -143,8 +145,10 @@ void ComicApplet::init()
 
     Plasma::ToolTipManager::self()->registerWidget( this );
 
-    loadConfig();
-
+    configChanged();
+    
+    buttonBar();
+    
     mEngine = dataEngine( "comic" );
     mModel = new ComicModel( mEngine->query( "providers" ), mTabIdentifier, this );
     mProxy = new QSortFilterProxyModel( this );
@@ -152,6 +156,12 @@ void ComicApplet::init()
     mProxy->setSortCaseSensitivity( Qt::CaseInsensitive );
     mProxy->sort( 1, Qt::AscendingOrder );
 
+    //set maximum number of cached strips per comic, -1 means that there is no limit
+    KConfigGroup global = globalConfig();
+    const bool useMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
+    const int maxComicLimit = global.readEntry( "maxComicLimit", 7 );
+    mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( useMaxComicLimit ? maxComicLimit : -1 ) );
+
     mCurrentDay = QDate::currentDate();
     mDateChangedTimer = new QTimer( this );
     connect( mDateChangedTimer, SIGNAL( timeout() ), this, SLOT( checkDayChanged() ) );
@@ -323,6 +333,10 @@ void ComicApplet::dataUpdated( const QString&, const Plasma::DataEngine::Data &d
 
     //there was an error, display information as image
     if ( data[ "Error" ].toBool() ) {
+        if ( !mShowErrorPicture && !data[ "Previous identifier suffix" ].toString().isEmpty() ) {
+            updateComic( data[ "Previous identifier suffix" ].toString() );
+            return;
+        }
         QPixmap errorPic( 500, 400 );
         errorPic.fill();
         QPainter p( &errorPic );
@@ -453,6 +467,7 @@ void ComicApplet::createConfigurationInterface( KConfigDialog *parent )
     mConfigWidget->setShowComicAuthor( mShowComicAuthor );
     mConfigWidget->setShowComicTitle( mShowComicTitle );
     mConfigWidget->setShowComicIdentifier( mShowComicIdentifier );
+    mConfigWidget->setShowErrorPicture( mShowErrorPicture );
     mConfigWidget->setArrowsOnHover( mArrowsOnHover );
     mConfigWidget->setMiddleClick( mMiddleClick );
     QTime time = QTime( mSwitchTabTime / 3600, ( mSwitchTabTime / 60 ) % 60, mSwitchTabTime % 60 );
@@ -462,9 +477,17 @@ void ComicApplet::createConfigurationInterface( KConfigDialog *parent )
     mConfigWidget->setSwitchTabs( mSwitchTabs );
     mConfigWidget->setTabView( mTabView - 1);//-1 because counting starts at 0, yet we use flags that start at 1
 
+    //not storing this value, since other applets might have changed it inbetween
+    KConfigGroup global = globalConfig();
+    const bool useMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
+    const int maxComicLimit = global.readEntry( "maxComicLimit", 7 );
+    mConfigWidget->setUseMaxComicLimit( useMaxComicLimit );
+    mConfigWidget->setMaxComicLimit( maxComicLimit );
+
     parent->setButtons( KDialog::Ok | KDialog::Cancel | KDialog::Apply );
     parent->addPage( mConfigWidget->comicSettings, i18n( "General" ), icon(), i18n( "Press the \"Get New Comics ...\" button to install comics." ) );
     parent->addPage( mConfigWidget->appearanceSettings, i18n( "Appearance" ), "image" );
+    parent->addPage( mConfigWidget->advancedSettings, i18n( "Advanced" ), "system-run" );
 
     connect( mConfigWidget, SIGNAL( maxSizeClicked() ), this, SLOT( slotShowMaxSize() ) );
     connect( parent, SIGNAL( applyClicked() ), this, SLOT( applyConfig() ) );
@@ -478,6 +501,7 @@ void ComicApplet::applyConfig()
     mShowComicAuthor = mConfigWidget->showComicAuthor();
     mShowComicTitle = mConfigWidget->showComicTitle();
     mShowComicIdentifier = mConfigWidget->showComicIdentifier();
+    mShowErrorPicture = mConfigWidget->showErrorPicture();
     mArrowsOnHover = mConfigWidget->arrowsOnHover();
     mMiddleClick = mConfigWidget->middleClick();
     const QTime time = mConfigWidget->tabSwitchTime();
@@ -487,6 +511,19 @@ void ComicApplet::applyConfig()
     mSwitchTabs = mConfigWidget->switchTabs();
     mTabView = mConfigWidget->tabView() + 1;//+1 because counting starts at 0, yet we use flags that start at 1
 
+    //not storing this value, since other applets might have changed it inbetween
+    KConfigGroup global = globalConfig();
+    const bool oldUseMaxComicLimit = global.readEntry( "useMaxComicLimit", false );
+    const bool useMaxComicLimit = mConfigWidget->useMaxComicLimit();
+    const int oldMaxComicLimit = global.readEntry( "maxComicLimit", 7 );
+    const int maxComicLimit = mConfigWidget->maxComicLimit();
+    if ( ( oldUseMaxComicLimit != useMaxComicLimit ) || ( oldMaxComicLimit != maxComicLimit ) ) {
+        global.writeEntry( "useMaxComicLimit", useMaxComicLimit );
+        global.writeEntry( "maxComicLimit", maxComicLimit );
+        mEngine->query( QLatin1String( "setting_maxComicLimit:" ) + QString::number( useMaxComicLimit ? maxComicLimit : -1 ) );
+    }
+
+
     updateUsedComics();
     slotStartTimer();
     saveConfig();
@@ -568,7 +605,7 @@ void ComicApplet::checkDayChanged()
     mCurrentDay = QDate::currentDate();
 }
 
-void ComicApplet::loadConfig()
+void ComicApplet::configChanged()
 {
     KConfigGroup cg = config();
     mTabIdentifier = cg.readEntry( "tabIdentifier", QStringList( QString() ) );
@@ -577,6 +614,7 @@ void ComicApplet::loadConfig()
     mShowComicAuthor = cg.readEntry( "showComicAuthor", false );
     mShowComicTitle = cg.readEntry( "showComicTitle", false );
     mShowComicIdentifier = cg.readEntry( "showComicIdentifier", false );
+    mShowErrorPicture = cg.readEntry( "showErrorPicture", true );
     mArrowsOnHover = cg.readEntry( "arrowsOnHover", true );
     mMiddleClick = cg.readEntry( "middleClick", true );
     mScaleComic = cg.readEntry( "scaleToContent_" + mComicIdentifier, false );
@@ -596,7 +634,7 @@ void ComicApplet::loadConfig()
     mSavingDir = cg.readEntry( "savingDir", QString() );
     mOldSource = mComicIdentifier + ':' + mStoredIdentifierSuffix;
 
-    buttonBar();
+    
 }
 
 void ComicApplet::saveConfig()
@@ -607,6 +645,7 @@ void ComicApplet::saveConfig()
     cg.writeEntry( "showComicAuthor", mShowComicAuthor );
     cg.writeEntry( "showComicTitle", mShowComicTitle );
     cg.writeEntry( "showComicIdentifier", mShowComicIdentifier );
+    cg.writeEntry( "showErrorPicture", mShowErrorPicture );
     cg.writeEntry( "arrowsOnHover", mArrowsOnHover );
     cg.writeEntry( "middleClick", mMiddleClick );
     cg.writeEntry( "switchTabTime", mSwitchTabTime );
