@@ -22,6 +22,8 @@
  */
 
 #include "leavenote.h"
+#include <kstandarddirs.h>
+#include <kmessagebox.h>
 
 #include <QtCore/QProcess>
 #include <QtCore/QHash>
@@ -54,6 +56,7 @@ LeaveNote::LeaveNote(QObject *parent, const QVariantList &args)
 {
     // this will get us the standard applet background, for free!
     setBackgroundHints(NoBackground);
+    setStatus(Plasma::AcceptingInputStatus);
     resize(340, 250);
     //setMinimumSize(300, 200); // replace with correct numbers
 }
@@ -66,8 +69,7 @@ void LeaveNote::init()
 {
     /* do config stuff */
     setHasConfigurationInterface(true);
-    KConfigGroup cg = config();
-    mUseKNotes = cg.readEntry("useKNotes", true);
+    configChanged();
 
     /* initialize layout */
     mTheme.setImagePath("widgets/notes");
@@ -147,7 +149,7 @@ void LeaveNote::createConfigurationInterface(KConfigDialog *dialog)
     ui.setupUi(widget);
 
     KConfigGroup cg = config();
-    ui.useKNotesCheckBox->setChecked(cg.readEntry("useKNotes", true));
+    ui.useKNotesCheckBox->setChecked(mUseKNotes);
 
     connect(dialog, SIGNAL(applyClicked()), this, SLOT(configAccepted()));
     connect(dialog, SIGNAL(okClicked()), this, SLOT(configAccepted()));
@@ -158,12 +160,16 @@ void LeaveNote::createConfigurationInterface(KConfigDialog *dialog)
 
 void LeaveNote::configAccepted()
 {
-    mUseKNotes = ui.useKNotesCheckBox->isChecked();
-
     KConfigGroup cg = config();
     cg.writeEntry("useKNotes", ui.useKNotesCheckBox->isChecked());
 }
 
+void LeaveNote::configChanged()
+{
+    KConfigGroup cg = config();
+    mUseKNotes = cg.readEntry("useKNotes", true);
+}
+
 bool LeaveNote::checkKNotesDBusInterface()
 {
     QDBusInterface knotesDBusTest("org.kde.knotes", "/KNotes", "org.freedesktop.DBus.Introspectable");
@@ -199,14 +205,20 @@ void LeaveNote::slotSend()
         if (mTimer && mTimer->isActive()) {
             return;
         }
+        if (KStandardDirs::findExe("knotes").isEmpty())
+        {
+            KMessageBox::error( 0, i18n( "knotes cannot be found. Please install it to be able to send a note." ) );
+        }
+        else
+        {
+            // TODO fine grain for errors after start of KNotes
+            QProcess knotes(this);
+            knotes.startDetached("knotes", QStringList() << "--skip-note");
+            knotes.waitForStarted();
 
-        // TODO fine grain for errors after start of KNotes
-        QProcess knotes(this);
-        knotes.startDetached("knotes", QStringList() << "--skip-note");
-        knotes.waitForStarted();
-
-        /* wait for the dbus interface to settle */
-        mTimer->singleShot(10000, this, SLOT(slotWaitForKNotes()));
+            /* wait for the dbus interface to settle */
+            mTimer->singleShot(10000, this, SLOT(slotWaitForKNotes()));
+        }
 
     } else {
         createNote(title, msg);
@@ -238,8 +250,8 @@ void LeaveNote::slotWaitForKNotes()
     }
 
     /* now we can empty the message cache */
-    QList<QHash<QString, QVariant> >::iterator i;
-    for (i = mMsgCache.begin(); i != mMsgCache.end(); ++i) {
+    QList<QHash<QString, QVariant> >::const_iterator i;
+    for (i = mMsgCache.constBegin(); i != mMsgCache.constEnd(); ++i) {
         createNote((*i)["title"].toString(),
                    (*i)["msg"].toString());
     }
