@@ -22,6 +22,7 @@
 #include <QGraphicsAnchorLayout>
 #include <QGraphicsLinearLayout>
 #include <QLabel>
+#include <QLocale>
 
 #include <KDateTime>
 #include <KColorScheme>
@@ -77,20 +78,6 @@ PostWidget::PostWidget(QGraphicsWidget *parent)
     //horizontal
     lay->addAnchor(lay, Qt::AnchorRight, m_from, Qt::AnchorRight);
     lay->addAnchors(lay, m_text, Qt::Horizontal);
-
-
-    QGraphicsItem *pw = this;
-    while ((pw = pw->parentItem())) {
-        Plasma::ScrollWidget *view = dynamic_cast<Plasma::ScrollWidget *>(pw);
-        if (view) {
-            view->registerAsDragHandle(m_from);
-            view->registerAsDragHandle(m_picture);
-            view->registerAsDragHandle(m_text);
-            view->registerAsDragHandle(m_replyButton);
-            view->registerAsDragHandle(m_forwardButton);
-            break;
-        }
-    }
 }
 
 PostWidget::~PostWidget()
@@ -99,6 +86,7 @@ PostWidget::~PostWidget()
 
 void PostWidget::setData(const Plasma::DataEngine::Data &data)
 {
+    m_messageId = data["Id"].toString();
     m_author->setText(data["User"].toString());
     QLocale english(QLocale::English, QLocale::UnitedStates);
     QDateTime dt = english.toDateTime(data.value( "Date" ).toString(), "ddd MMM dd HH:mm:ss +0000 yyyy");
@@ -123,12 +111,14 @@ void PostWidget::setColorScheme(KColorScheme *scheme)
 
 void PostWidget::askReply()
 {
-    emit reply('@' + m_author->text() + ' ');
+    emit reply(m_messageId, '@' + m_author->text() + ' ');
 }
 
 void PostWidget::askForward()
 {
-    emit forward(QChar(0x267B) + QString(" @") + m_author->text() + ' ' + m_text->nativeWidget()->toPlainText());
+    //Change !abc to #abc when forwarding, good etiquette
+    const QString forwardText = m_text->nativeWidget()->toPlainText().replace(QRegExp("\\!(\\w)"), "#\\1");
+    emit forward(QChar(0x267B) + QString(" @") + m_author->text() + ' ' + forwardText);
 }
 
 void PostWidget::askProfile()
