@@ -22,17 +22,22 @@
 #include "Helpers.h"
 #include <QPainter>
 
+#include <Plasma/Theme>
+
 ArrowBottomKey::ArrowBottomKey(QPoint relativePosition, QSize relativeSize) :
-        FuncKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Down), QString()){
+        FuncKey(relativePosition, relativeSize, Helpers::keysymToKeycode(XK_Down), QString())
+{
 
 }
 
-void ArrowBottomKey::paint(QPainter *painter){
+void ArrowBottomKey::paint(QPainter *painter)
+{
     FuncKey::paint(painter);
 
     painter->save();
     setUpPainter(painter);
     painter->setRenderHint(QPainter::Antialiasing);
+    painter->setPen(Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor));
 	painter->rotate(-90);
 	paintArrow(painter);
     painter->restore();
